@@ -5,7 +5,7 @@
  * Horde_Mime_Viewer_* drivers which handle the actual rendering, and a
  * configuration file to map MIME types to drivers.
  *
- * Copyright 1999-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -35,7 +35,7 @@ class Horde_Mime_Viewer
      * @return Horde_Mime_Viewer_Base  The newly created concrete instance.
      * @throws Horde_Mime_Viewer_Exception
      */
-    static public function factory($driver, $part, array $params = array())
+    public static function factory($driver, $part, array $params = array())
     {
         $params['_driver'] = $driver;
 
